netapp_ontap.models.consistency_group_snaplock_retention API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_snaplock_retention`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupSnaplockRetentionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupSnaplockRetention object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `default: str GET POST PATCH`

    Specifies the default retention period that is applied to objects within a consistency group while committing them to the WORM state without an associated retention period.

    Example: P6M

  `maximum: str GET POST PATCH`

    Specifies the maximum allowed retention period for objects committed to the WORM state on the consistency group.

    Example: P30Y

  `minimum: str GET POST PATCH`

    Specifies the minimum allowed retention period for objects within a consistency group committed to the WORM state on the consistency group.

    Example: P30Y